scoretools.make_repeated_notes_from_time_signature
==================================================

.. autofunction:: abjad.tools.scoretools.make_repeated_notes_from_time_signature.make_repeated_notes_from_time_signature
